AnalyticsResource class
Analytics resource
Constructors
- AnalyticsResource(OpenRouter client)
- Creates a new analytics resource.
Properties
- client → OpenRouter
-
The OpenRouter client used to perform requests.
finalinherited
- dio → Dio
-
The underlying Dio instance used for HTTP requests.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T> (Future< Response< future) → Future<T> >T> -
Awaits
futureand returns its decoded data, mapping errors to SDK exceptions.inherited -
getUserActivity(
{DateTime? date, String? apiKeyHash, String? userId}) → Future< List< Activity> > - Returns user activity data grouped by endpoint. Management key required.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited