ImageGenerationConfig class
Configuration for image generation requests.
Constructors
-
ImageGenerationConfig({ImageQuality? quality, ImageResolution? resolution, AspectRatio? aspectRatio, BackgroundStyle? background, ImageFormat? format, int? compressionLevel, Map<
String, dynamic> ? additionalProperties}) - Create an ImageGenerationConfig instance.
Properties
-
additionalProperties
→ Map<
String, dynamic> ? -
Additional provider-specific properties.
final
- aspectRatio → AspectRatio?
-
Aspect ratio of the generated image.
final
- background → BackgroundStyle?
-
Background style of the generated image.
final
- compressionLevel → int?
-
Compression level (0-100) of the generated image.
final
- format → ImageFormat?
-
Output format of the generated image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality → ImageQuality?
-
Quality of the generated image.
final
- resolution → ImageResolution?
-
Resolution of the generated image.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert this configuration to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited